

/** @file test.cpp
 *  @brief MF2Lib Change Detection library test.
 *
 *  @author Federico Tombari
 */


#include <iostream>
#include "MF2lib.h"

int main()
{
    std::cout << "MF2Lib Change Detection Test" << std::endl;
	std::cout << "Press Enter to start test." << std::endl;
	std::cin.get();

	// parameters of the algorithm
	int sbl = 5;		//block radius
	float mf_th = 0.6f;	//intermediate threshold
	int diff_th = 40;	//final pixel-wise threshold
	
	std::cout << "Parameters of algorithm:" << std::endl;
	std::cout << "\tSBL = " << sbl << std::endl;
	std::cout << "\tMF Threshold = " << mf_th << std::endl;
	std::cout << "\tdiff Threshold = " << diff_th << std::endl;

	cv::Mat frameColor, frame, bg;

	cv::VideoCapture cap(0);
	cap >> frameColor;

	cv::cvtColor(frameColor, bg, CV_BGR2GRAY);
	IplImage bgIpl = bg;
	cv::Mat cm(bg.rows, bg.cols, CV_8UC1);

	//Init Background
	mf2BackgroundModeling(&bgIpl, sbl);
	
	cv::imshow("background", bg);

	int key = 'a';
	while(key != 'q'){

		cap >> frameColor;

		cv::cvtColor(frameColor, frame, CV_BGR2GRAY);

		IplImage frameIpl = frame;
		IplImage cmIpl = cm;

		//compute change detection on current frame
		mf2ChangeDetection(&frameIpl, &bgIpl, &cmIpl, sbl, mf_th, diff_th);
		
		cv::imshow("frame", frame);
		cv::imshow("change mask", cm);
		key = cvWaitKey(10);
		
	}

	return 0;
} 